Structs
- Http
Connect Limits - Configuration limits for HTTP CONNECT response parsing.
Functions
- http_
connect - Send an HTTP CONNECT request to an upstream proxy and return the upgraded stream on success.
- parse_
status_ code - Parse the HTTP status code from a response head string.
- validate_
credentials - Validate that a credential string contains no control characters.