Module server

Module server 

Structs

BodyCopyLimits
Limits for body copying.
BodyCopyReport
Report from body copying.
ForwardRequest
A parsed HTTP request ready for forwarding.
ForwardResponse
Parsed HTTP response from an upstream server.
ForwardResponseReport
Report from forwarding a response.
ForwardResult
Result of forwarding a response, including upstream connection state.

Enums

RequestBodyKind
Describes how the request body is framed.

Functions

build_origin_request
Build an origin-form HTTP request to send to the upstream server.
copy_request_body
Copy a request body from reader to writer.
determine_request_body_kind
Determine the request body framing from parsed headers.
filter_hop_by_hop
Filter hop-by-hop headers from a header list, returning only end-to-end headers.
forward_request
Forward an HTTP request from a client to the target server.
forward_request_stream
Read and parse an HTTP forward request from an existing stream.
forward_response
Forward the upstream response back to the client stream.
has_unsupported_expectation
Return whether the request contains an expectation this forwarder cannot negotiate. Expectation values are collected case-insensitively and comma- separated values are treated independently.