Module client

Module client 

Structs

HttpConnectLimits
Configuration limits for HTTP CONNECT response parsing.

Functions

http_connect
Send an HTTP CONNECT request to an upstream proxy and return the upgraded stream on success.
parse_status_code
Parse the HTTP status code from a response head string.
validate_credentials
Validate that a credential string contains no control characters.