Structs
- Body
Copy Limits - Limits for body copying.
- Body
Copy Report - Report from body copying.
- Forward
Request - A parsed HTTP request ready for forwarding.
- Forward
Response - Parsed HTTP response from an upstream server.
- Forward
Response Report - Report from forwarding a response.
- Forward
Result - Result of forwarding a response, including upstream connection state.
Enums
- Request
Body Kind - Describes how the request body is framed.
Functions
- build_
origin_ request - Build an origin-form HTTP request to send to the upstream server.
- copy_
request_ body - Copy a request body from reader to writer.
- determine_
request_ body_ kind - Determine the request body framing from parsed headers.
- filter_
hop_ by_ hop - Filter hop-by-hop headers from a header list, returning only end-to-end headers.
- forward_
request - Forward an HTTP request from a client to the target server.
- forward_
request_ stream - Read and parse an HTTP forward request from an existing stream.
- forward_
response - Forward the upstream response back to the client stream.
- has_
unsupported_ expectation - Return whether the request contains an expectation this forwarder cannot negotiate. Expectation values are collected case-insensitively and comma- separated values are treated independently.